/* 
 * Midway Distributed Shared Memory System
 * Copyright (c) 1994 Carnegie Mellon University
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify and distribute this software and its
 * documentation is hereby granted, provided that both the copyright
 * notice and this permission notice appear in all copies of the
 * software, derivative works or modified versions, and any portions
 * thereof, and that both notices appear in supporting documentation.
 * 
 * CARNEGIE MELLON ALLOWS FREE USE OF THIS SOFTWARE IN ITS "AS IS"
 * CONDITION.  CARNEGIE MELLON DISCLAIMS ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 */
/*
 * timing.h: support for timing statistics
 */
#include <sys/time.h>		/* for timevals, and other good things */

typedef struct timeval tv_t;
#define NOZONE (struct timezone *) 0
#define TV_TO_DOUBLE(x) ((double)(x).tv_sec + \
    ((double) (x).tv_usec / 1000000.0))
 
typedef struct timestat {
  double sum;			/* sum of all values */
  double sumsq;			/* sq of sum of all values */
  double mean;			/* the mean */
  double var;			/* the variance */
  double sdev;			/* the standard deviation */
  unsigned long count;		/* number of values */
} timestat_t, *timestatp_t;

/*
 * compute difference between two timevals; plavce into timeval
 */
void
time_diff( /* 	tv_t *start,	gettimeofday() at start
		tv_t *end,	value at end
		tv_t *result	the difference end-start
	    */);

/*
 * time_init: initialize a timestat struct.  Must call before time_add
 *	or time_stat.
 */
void
time_init( /*	timestat_t *ts */ );

/*
 * time_add: add a new datapoint into the stat struct
 */
double
time_add( /*	tv_t *start,		the starting time
		tv_t *end,		the ending time
		timestat_t *ts,		the timestat structure to fill
		int num		num of iterations btwn start & end
	   */);
/*
 * time_stat: compute statistics on a timestat struct
 */
void
time_stat( /* timesytat_t *ts */);
